@@ -2,16 +2,16 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2018-2023, by Samuel Williams.
+# Copyright, 2018-2025, by Samuel Williams.
 # Copyright, 2021, by Ye Lin Aung.
 
 # Require the required libraries:
-require 'async'
-require 'async/io/host_endpoint'
-require 'async/io/ssl_endpoint'
-require 'async/http/server'
-require 'async/http/client'
-require 'localhost'
+require "async"
+require "async/io/host_endpoint"
+require "async/io/ssl_endpoint"
+require "async/http/server"
+require "async/http/client"
+require "localhost"
 
 # The (self-signed) authority to use:
 hostname = "localhost"
